@@ -328,23 +328,27 @@ draw_Lifemap <- function(lm_obj){
         }
     }
     
-    
-    
-    
-    
     ui <- shiny::fluidPage(
         htmltools::tags$head(
             htmltools::tags$style(
-                htmltools::HTML(".leaflet-container {
+                htmltools::HTML("
+            .leaflet-container {
              background: #000000;
              outline: 0;
             }
+            .container-fluid {
+                padding:0px;
+            }
+            #mymap {
+                width:100% !important;
+                height:100% !important;
+                position:fixed !important;
+            }
            ")
             )),
         
-        
-        htmltools::tags$style(type = "text/css", "html, body {width:100%;height:100%}"),
-        leaflet::leafletOutput("mymap", width = "100%", height = "1000px"),
+        # htmltools::tags$style(type = "text/css", "#mymap {height: calc(100vh) !important; }"),
+        leaflet::leafletOutput("mymap"),
         htmltools::p()
     )
     
